@@ -125,7 +125,7 @@ func startControllers(ctx *ControllerContext) {
 		ctx.ClientBuilder.KubeClientOrDie(componentName),
 		ctx.ClientBuilder.OpenshiftClientOrDie(componentName),
 		recorder,
-	).Run(2, ctx.Stop)
+	).Run(1, ctx.Stop)
 }
 
 func startMetricsCollectionAndServer(ctx *ControllerContext) {
@@ -145,7 +145,7 @@ func startMetricsCollectionAndServer(ctx *ControllerContext) {
 		metricsPort = v
 	}
 	glog.V(4).Info("Starting server to serve prometheus metrics")
-	go startHTTPMetricServer(fmt.Sprintf(":%d", metricsPort))
+	go startHTTPMetricServer(fmt.Sprintf("localhost:%d", metricsPort))
 }
 
 func startHTTPMetricServer(metricsPort string) {
